@@ -1,5 +1,5 @@
 # comtypes version numbers follow semver (http://semver.org/) and PEP 440
-__version__ = "1.4.7"
+__version__ = "1.4.9"
 
 try:
     from _ctypes import COMError  # noqa
@@ -25,6 +25,7 @@ from ctypes import *  # noqa
 from ctypes import HRESULT  # noqa
 from ctypes import _Pointer, _SimpleCData  # noqa
 from ctypes import c_int, c_ulong, oledll, windll
+from ctypes.wintypes import DWORD  # noqa
 import logging
 import sys
 from typing import TYPE_CHECKING
@@ -39,9 +40,6 @@ from comtypes.GUID import GUID
 from comtypes import patcher  # noqa
 from comtypes._npsupport import interop as npsupport  # noqa
 from comtypes._tlib_version_checker import _check_version  # noqa
-from comtypes._py_instance_method import instancemethod  # noqa
-from comtypes._idl_stuff import defaultvalue, helpstring, dispid  # noqa
-from comtypes._idl_stuff import STDMETHOD, DISPMETHOD, DISPPROPERTY, COMMETHOD  # noqa
 
 _all_slice = slice(None, None, None)
 
@@ -75,7 +73,6 @@ class ReturnHRESULT(Exception):
 
 _GUID = GUID
 IID = GUID
-DWORD = c_ulong
 
 wireHWND = c_ulong
 
@@ -172,6 +169,19 @@ com_interface_registry = {}
 com_coclass_registry = {}
 
 
+################################################################
+# IDL stuff
+
+from comtypes._memberspec import (  # noqa
+    COMMETHOD,
+    DISPMETHOD,
+    DISPPROPERTY,
+    STDMETHOD,
+    defaultvalue,
+    dispid,
+    helpstring,
+)
+
 ################################################################
 # IUnknown, the root of all evil...
 from comtypes._post_coinit import _shutdown
@@ -193,6 +203,7 @@ from comtypes._post_coinit.misc import IPersist, IServiceProvider  # noqa
 ################################################################
 
 
+from comtypes._post_coinit.instancemethod import instancemethod  # noqa
 from comtypes._post_coinit.misc import (  # noqa
     _is_object,
     CoGetObject,
