@@ -2,31 +2,26 @@
 import array
 import datetime
 import decimal
-import sys
+from _ctypes import COMError, CopyComPointer
 from ctypes import *
-from ctypes import _Pointer, Array as _CArrayType
-from _ctypes import CopyComPointer
+from ctypes import Array as _CArrayType
+from ctypes import _Pointer
 from ctypes.wintypes import DWORD, LONG, UINT, VARIANT_BOOL, WCHAR, WORD
-from typing import Any, ClassVar, Dict, List, Optional, TYPE_CHECKING, Type
+from typing import TYPE_CHECKING, Any, ClassVar, Dict, List, Optional, Type
 
-from comtypes import _CData, BSTR, COMError, COMMETHOD, GUID, IID, IUnknown, STDMETHOD
-from comtypes.hresult import *
-from comtypes._memberspec import _DispMemberSpec
-import comtypes.patcher
 import comtypes
+import comtypes.patcher
+from comtypes import BSTR, COMMETHOD, GUID, IID, STDMETHOD, IUnknown, _CData, _safearray
+from comtypes import hresult as hresult
+from comtypes.safearray import _midlSAFEARRAY
 
 if TYPE_CHECKING:
     from ctypes import _CArgObject
+
     from comtypes import hints  # type: ignore
-    from comtypes import _safearray
+    from comtypes._memberspec import _DispMemberSpec
 else:
     _CArgObject = type(byref(c_int()))
-    try:
-        from comtypes import _safearray
-    except (ImportError, AttributeError):
-
-        class _safearray(object):
-            tagSAFEARRAY = None
 
 
 LCID = DWORD
@@ -212,14 +207,14 @@ class tagVARIANT(Structure):
 
     def __repr__(self):
         if self.vt & VT_BYREF:
-            return "VARIANT(vt=0x%x, byref(%r))" % (self.vt, self[0])
+            return f"VARIANT(vt=0x{self.vt:x}, byref({self[0]!r}))"
         elif self is type(self).null:
             return "VARIANT.null"
         elif self is type(self).empty:
             return "VARIANT.empty"
         elif self is type(self).missing:
             return "VARIANT.missing"
-        return "VARIANT(vt=0x%x, %r)" % (self.vt, self.value)
+        return f"VARIANT(vt=0x{self.vt:x}, {self.value!r})"
 
     @classmethod
     def from_param(cls, value):
@@ -428,7 +423,7 @@ class tagVARIANT(Structure):
             else:
                 self.vt = _ctype_to_vartype[type(ref)] | VT_BYREF
         else:
-            raise TypeError("Cannot put %r in VARIANT" % value)
+            raise TypeError(f"Cannot put {value!r} in VARIANT")
         # buffer ->  SAFEARRAY of VT_UI1 ?
 
     # c:/sf/pywin32/com/win32com/src/oleargs.cpp 197
@@ -524,7 +519,7 @@ class tagVARIANT(Structure):
             typ = _vartype_to_ctype[self.vt & ~VT_ARRAY]
             return cast(self._.pparray, _midlSAFEARRAY(typ)).unpack()
         else:
-            raise NotImplementedError("typecode %d = 0x%x)" % (vt, vt))
+            raise NotImplementedError(f"typecode {vt} = 0x{vt:x})")
 
     def __getitem__(self, index):
         if index != 0:
@@ -714,17 +709,16 @@ class tagEXCEPINFO(Structure):
         scode: int
 
     def __repr__(self):
-        return "<EXCEPINFO %s>" % (
-            (
-                self.wCode,
-                self.bstrSource,
-                self.bstrDescription,
-                self.bstrHelpFile,
-                self.dwHelpContext,
-                self.pfnDeferredFillIn,
-                self.scode,
-            ),
+        info = (
+            self.wCode,
+            self.bstrSource,
+            self.bstrDescription,
+            self.bstrHelpFile,
+            self.dwHelpContext,
+            self.pfnDeferredFillIn,
+            self.scode,
         )
+        return f"<EXCEPINFO {info}>"
 
 
 tagEXCEPINFO._fields_ = [
@@ -775,7 +769,7 @@ DISPID_COLLECT = -8
 
 
 class IDispatch(IUnknown):
-    _disp_methods_: ClassVar[List[_DispMemberSpec]]
+    _disp_methods_: ClassVar[List["_DispMemberSpec"]]
 
     _iid_ = GUID("{00020400-0000-0000-C000-000000000046}")
     _methods_ = [
@@ -812,6 +806,10 @@ class IDispatch(IUnknown):
         ),
     ]
 
+    if TYPE_CHECKING:
+
+        def GetTypeInfoCount(self) -> int: ...
+
     def GetTypeInfo(self, index: int, lcid: int = 0) -> "hints.ITypeInfo":
         """Return type information.  Index 0 specifies typeinfo for IDispatch"""
         import comtypes.typeinfo
@@ -894,8 +892,8 @@ class IDispatch(IUnknown):
                 byref(argerr),
             )
         except COMError as err:
-            (hresult, text, details) = err.args
-            if hresult == DISP_E_EXCEPTION:
+            (hr, text, details) = err.args
+            if hr == hresult.DISP_E_EXCEPTION:
                 details = (
                     excepinfo.bstrDescription,
                     excepinfo.bstrSource,
@@ -903,24 +901,22 @@ class IDispatch(IUnknown):
                     excepinfo.dwHelpContext,
                     excepinfo.scode,
                 )
-                raise COMError(hresult, text, details)
-            elif hresult == DISP_E_PARAMNOTFOUND:
+                raise COMError(hr, text, details)
+            elif hr == hresult.DISP_E_PARAMNOTFOUND:
                 # MSDN says: You get the error DISP_E_PARAMNOTFOUND
                 # when you try to set a property and you have not
                 # initialized the cNamedArgs and rgdispidNamedArgs
                 # elements of your DISPPARAMS structure.
                 #
                 # So, this looks like a bug.
-                raise COMError(hresult, text, argerr.value)
-            elif hresult == DISP_E_TYPEMISMATCH:
+                raise COMError(hr, text, argerr.value)
+            elif hr == hresult.DISP_E_TYPEMISMATCH:
                 # MSDN: One or more of the arguments could not be
                 # coerced.
                 #
                 # Hm, should we raise TypeError, or COMError?
                 raise COMError(
-                    hresult,
-                    text,
-                    ("TypeError: Parameter %s" % (argerr.value + 1), args),
+                    hr, text, (f"TypeError: Parameter {argerr.value + 1}", args)
                 )
             raise
         return result._get_value(dynamic=True)
@@ -960,6 +956,7 @@ _ctype_to_vartype: Dict[Type[_CData], int] = {
     c_ulonglong: VT_UI8,
     VARIANT_BOOL: VT_BOOL,
     BSTR: VT_BSTR,
+    HRESULT: VT_HRESULT,
     VARIANT: VT_VARIANT,
     # SAFEARRAY(VARIANT *)
     #
@@ -991,12 +988,6 @@ _vartype_to_ctype[VT_UINT] = _vartype_to_ctype[VT_UI4]
 _ctype_to_vartype[c_char] = VT_UI1
 
 
-try:
-    from comtypes.safearray import _midlSAFEARRAY
-except (ImportError, AttributeError):
-    pass
-
-
 # fmt: off
 __known_symbols__ = [
     "CURRENCY", "CY", "tagCY", "DECIMAL", "tagDEC", "DISPATCH_METHOD",
